[llvm] r280358 - Add an optional parameter with a list of undefs to extendToIndices

Krzysztof Parzyszek via llvm-commits llvm-commits at lists.llvm.org
Thu Sep 1 05:10:37 PDT 2016


Author: kparzysz
Date: Thu Sep  1 07:10:36 2016
New Revision: 280358

URL: http://llvm.org/viewvc/llvm-project?rev=280358&view=rev
Log:
Add an optional parameter with a list of undefs to extendToIndices

Reapply r280268, hopefully in a version that MSVC likes.

Modified:
    llvm/trunk/include/llvm/CodeGen/LiveIntervalAnalysis.h
    llvm/trunk/lib/CodeGen/LiveIntervalAnalysis.cpp

Modified: llvm/trunk/include/llvm/CodeGen/LiveIntervalAnalysis.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/CodeGen/LiveIntervalAnalysis.h?rev=280358&r1=280357&r2=280358&view=diff
==============================================================================
--- llvm/trunk/lib/CodeGen/LiveIntervalAnalysis.cpp (original)
+++ llvm/trunk/lib/CodeGen/LiveIntervalAnalysis.cpp Thu Sep  1 07:10:36 2016
@@ -568,11 +568,12 @@ void LiveIntervals::shrinkToUses(LiveInt
 }
 
 void LiveIntervals::extendToIndices(LiveRange &LR,
-                                    ArrayRef<SlotIndex> Indices) {
+                                    ArrayRef<SlotIndex> Indices,
+                                    ArrayRef<SlotIndex> Undefs) {
   assert(LRCalc && "LRCalc not initialized.");
   LRCalc->reset(MF, getSlotIndexes(), DomTree, &getVNInfoAllocator());
   for (unsigned i = 0, e = Indices.size(); i != e; ++i)
-    LRCalc->extend(LR, Indices[i], /*PhysReg=*/0, /*Undefs=*/{});
+    LRCalc->extend(LR, Indices[i], /*PhysReg=*/0, Undefs);
 }
 
 void LiveIntervals::pruneValue(LiveRange &LR, SlotIndex Kill,




More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/CodeGen/LiveIntervalAnalysis.h (original)
+++ llvm/trunk/include/llvm/CodeGen/LiveIntervalAnalysis.h Thu Sep  1 07:10:36 2016
@@ -164,14 +164,23 @@ extern cl::opt<bool> UseSegmentSetForPhy
     void shrinkToUses(LiveInterval::SubRange &SR, unsigned Reg);
 
     /// Extend the live range @p LR to reach all points in @p Indices. The
     /// points in the @p Indices array must be jointly dominated by existing
     /// defs in @p LR. PHI-defs are added as needed to maintain SSA form.
     ///
     /// If a SlotIndex in @p Indices is the end index of a basic block, @p LR
     /// will be extended to be live out of the basic block.
+    /// If a SlotIndex in @p Indices is jointy dominated only by points in
+    /// @p Undefs, the live range will not be extended to that point.
     ///
     /// See also LiveRangeCalc::extend().
-    void extendToIndices(LiveRange &LR, ArrayRef<SlotIndex> Indices);
+    void extendToIndices(LiveRange &LR, ArrayRef<SlotIndex> Indices,
+                         ArrayRef<SlotIndex> Undefs);
+
+    void extendToIndices(LiveRange &LR, ArrayRef<SlotIndex> Indices) {
+      extendToIndices(LR, Indices, /*Undefs=*/{});
+    }
 
     /// If @p LR has a live value at @p Kill, prune its live range by removing
     /// any liveness reachable from Kill. Add live range end points to
@@ -164,14 +164,23 @@ extern cl::opt<bool> UseSegmentSetForPhy
 
     /// Extend the live range @p LR to reach all points in @p Indices. The
-    /// points in the @p Indices array must be jointly dominated by existing
-    /// defs in @p LR. PHI-defs are added as needed to maintain SSA form.
+    /// points in the @p Indices array must be jointly dominated by the union
+    /// of the existing defs in @p LR and points in @p Undefs.
+    ///
+    /// PHI-defs are added as needed to maintain SSA form.
     ///
     /// If a SlotIndex in @p Indices is the end index of a basic block, @p LR

Modified: llvm/trunk/lib/CodeGen/LiveIntervalAnalysis.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/LiveIntervalAnalysis.cpp?rev=280358&r1=280357&r2=280358&view=diff
==============================================================================